function reject = benjamini(pvals,fdr)

% accept = benjamini(pvals,fdr)
%
% Benjamini & Hochberg's (J. Royal Statistical Society B,1995) method for
% controlling the false discovery rate for multiple comparisons.
%
% pvals  : a list of (uncorrected) p-values for the individual comparisons
% fdr    : the desired false discovery rate. Default: .05
%
% Returns a list of the indices (corresponding to "pvals") of the
% comparisons that result in rejected null hypotheses (i.e., significant
% effects).

pvals = pvals(:)';

if nargin < 2
    fdr = .05;
end

nrcomp       = length(pvals);
[pvals,ind]  = sort(pvals);

reject = ind(1:find(pvals <= fdr*(1:nrcomp)/nrcomp,1,'last'));
